Page 54 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 54

Home

    Commenting upon the attack against religion and
    morality during the French Revolution, John Robison
    stated:

    of the world, the attack has been first made on the
    principles of Morality and Religion. The conspirators
    saw that till these are extripated, they have no chance of
    success; and their manner of proceeding shews that they
    consider Religion and Morality as inseparably connected
    together.'?

    After the death of the King in 1793, the leaders of the
    evolution, who now had total control of the

    government, set out to make terror the order of the day.
    This terror was not only applied to the common people
    but to each other as well. Robespierre and his followers,
    drunk with power, set out to wage war on civilization in
    the name of Socialism.

    The great criminals of history were not the people
    inspired by the worst motives, but the people for whom
    this distinction did not exist ... the doctrine that has

    produced all the worst atrocities in the history of the
    civilized world — namely, that "the end justifies the
    means" ... the community or nation which accepts the
    belief that everything is justifiable — lying, duplicity,
    treachery, and murder — in order to benefit the cause it
    has embraced, sells its soul to the devil. To hold this

    49

    The French Revolution

    ... In all those villainous machinations against the peace

    Revolution,

    Rationale for the acts that were to follow was

    expressed in this manner by Nesta Webster: